@@ -1,4 +1,11 @@
 #!/usr/bin/perl
+
+=head1 NAME
+
+Geo-GoogleEarth-Pluggable-Point-StyleIcon.pl - Geo-GoogleEarth-Pluggable Icon Style Example
+
+=cut
+
 use strict;
 use warnings;
 use Geo::GoogleEarth::Pluggable;
@@ -6,7 +13,7 @@ use DateTime;
 
 my $document=Geo::GoogleEarth::Pluggable->new(name=>sprintf("Style Example - %s", DateTime->now));
 
-my $IconStyleBlueDot=$document->IconStyle(
+my $IconStyleBlueDot=$document->IconStyle( #This is also simply IconStyleBlueDot()
                color   => {red=>0, green=>0, blue=>192},
                scale   => 1.2,
                href    => "http://maps.google.com/mapfiles/kml/shapes/shaded_dot.png",
